This class encapsulates the other R6 Class elements that define an IncidenceDesign
Value
A IncidenceDesign R6 object that stores the full cohort incidence analysis design, including cohort definitions, target definitions, outcomes, time-at-risk definitions, analyses, subgroups, strata settings, and study window metadata used to generate SQL.
Details
The IncidenceDesign class encapsulates the following:
Cohort Definitions
Target Definitions
Outcome Definitions
Time At Risk Definitions
A List of Analyses
Concept Sets
Subgruops
Strata Settings Note, when serializing with a library such as jsonlite, first call toList() on the R6 class before calling jsonlite::toJSON(), or call toJSON directy on this class.
Active bindings
cohortDefsA list of cohort definitions. Must be a list of CohortDefinition
conceptSetsA list of concept set expressions. Currently unused.
targetDefsA list of cohort references to be used as target cohorts. Must be a list of CohortReference
outcomeDefsA list of outcome definitions. Must be a list of Outcome
timeAtRiskDefsA list of time-at-risk definitions. Must be a list of TimeAtRisk
analysisListA list of analyses, containing the T-O-TAR combinations to perform. Must be a list of IncidenceAnalysis
subgroupsA list of subgroups. Must be a list of CohortSubgroup
strataSettingsThe strata settings for this design. Must be a class StrataSettings
studyWindowa study window for this design. Must be a list of class DateRange
firstAtRiska boolean indicating to limit TAR to first per person.
firstPostOutcomea boolean indicating to limit TAR to first per person.
Methods
IncidenceDesign$new()
creates a new instance, using the provided data param if provided.
Usage
IncidenceDesign$new(data = list())