Builds SQL code to run analyses according given Cohort Characterization design
Source:R/CohortIncidenceQueryBuilder.R
buildQuery.RdBuilds SQL code to run analyses according given Cohort Characterization design
Value
SQL code in MS Sql Server dialect, if it's required to run analysis on another DBMS
you have to use translateSql function in the SqlRender package.