Creates R6 object for Outcome
Arguments
- id
the unique identifier for this outcome definition
- name
an optional name for this outcome definition
- cohortId
the cohort id reference for this outcome
- cleanWindow
the number of days to extend the outcome cohort’s end date. See
executeAnalysis()for details on how this is applied.- excludeCohortId
a cohort ID from the outcomeCohrotTable that is used to exclude time at risk. See
executeAnalysis()for details on how this is applied.