The CohortReference class, encapsulating the id, name and descritpion fields that refernces a cohort definition.
Value
A CohortReference R6 object that stores the cohort id, display name, and optional description used to reference a target, outcome, or subgroup cohort.
Details
This class is used to reference a cohort definition by ID, while providing a way to substitute a name for this specific reference.
Note, when serializing with a library such as jsonlite, first call toList() on the R6 class before calling jsonlite::toJSON().
Active bindings
idthe cohort id being referenced
namethe name for the cohort to be used in this reference.
descriptionA description for this Cohort Reference.
Methods
CohortReference$new()
creates a new instance, using the provided data param if provided.
Usage
CohortReference$new(data = list())