The IncidenceAnalysis class, encapsulating the targets, outcomes and tars.
Value
A IncidenceAnalysis R6 object that stores the analysis combination as three integer ID vectors: targets, outcomes, and time-at-risk definitions.
Details
The targets, outcomes and tars fields are referencing IDs of the targetDef, outcomeDef and tarDefs R6 classes.
Note, when serializing with a library such as jsonlite, first call toList() on the R6 class before calling jsonlite::toJSON().
Active bindings
targetsA vector of target IDs from target definitions. Must be a vector.
outcomesA vector of outcome IDs from outcome definitions. Must be a vector.
tarsA vector of TAR IDs from time-at-risk definitions. Must be a vector.
Methods
IncidenceAnalysis$new()
creates a new instance, using the provided data param if provided.
Usage
IncidenceAnalysis$new(data = list())