R6 Class Representing the Stratification Settings of a IncidenceDesign
Source:R/Classes.R
StrataSettings.RdThe StrataSettings class, encapsulating the age, gender and start-year + age breaks settings.
Value
A StrataSettings R6 object that stores the age, gender, year, and age-break stratification options used during analysis.
Note, when serializing with a library such as jsonlite, first call toList() on the R6 class before calling jsonlite::toJSON().
Details
This class is used to specify the stratification settings for an analysis. The settings can indicate the statistics should be grouped by the age, gender, or start year, and any combination of those selections.
Example: age = TRUE and gender = TRUE will produce statisics by age, by gender, and by age and gender.
Active bindings
byAgeenables stratification by age
byGenderenables stratification by gender
byYearenables stratification by start year of TAR
ageBreaksa list of age breaks with at least 1 member
ageBreakLista list of age breaks
Methods
StrataSettings$new()
creates a new instance, using the provided data param if provided.
Usage
StrataSettings$new(data = list())