Creates R6 object for CohortReference
Usage
createCohortRef(id, name, description)
Arguments
- id
the cohort id that is being referenced
- name
the name to use for this reference
- description
an optional description to use for this reference.
Value
A CohortReference R6 object that stores the cohort identifier, display name, and optional description used to reference a cohort definition in the design.